@@ -31,6 +31,7 @@ from otopi import util
 from ovirt_host_deploy import hardware
 
 from ovirt_hosted_engine_setup import constants as ohostedcons
+from ovirt_hosted_engine_setup import vds_info
 
 
 def _(m):
@@ -107,10 +108,9 @@ class Plugin(plugin.PluginBase):
         super(Plugin, self).__init__(context=context)
 
     def _getCompatibleCpuModels(self):
-        cli = self.environment[ohostedcons.VDSMEnv.VDS_CLI]
-        caps = cli.getVdsCapabilities()
-        if caps['status']['code'] != 0:
-            raise RuntimeError(caps['status']['message'])
+        caps = vds_info.capabilities(
+            self.environment[ohostedcons.VDSMEnv.VDS_CLI]
+        )
         cpuModel = caps['cpuModel']
         cpuCompatibles = [
             x for x in caps['cpuFlags'].split(',')
